@@ -8,6 +8,7 @@ from typing import Union
 from torch.nn import ReLU, Tanh
 
 from hbrl.utils import create_dir
+from ..utils import scale_tensor
 from ..value_based_agent import ValueBasedAgent
 from ..utils.mlp import MLP
 from torch import optim
@@ -57,7 +58,7 @@ class DDPG(ValueBasedAgent):
             action = action.cpu().detach().numpy()
 
             # Fit action to our action_space
-            action = self.scale_action(action, Box(-1, 1, (self.nb_actions,)))
+            action = scale_tensor(action, Box(-1, 1, (self.nb_actions,)), self.action_space)
         return action
 
     def learn_interaction(self, *interaction_data):
@@ -82,7 +83,7 @@ class DDPG(ValueBasedAgent):
 
             with torch.no_grad():
                 target_actions = self.target_actor(new_states)
-                target_actions = self.scale_action(target_actions, Box(-1, 1, (self.nb_actions,)))
+                target_actions = scale_tensor(target_actions, Box(-1, 1, (self.nb_actions,)), self.action_space)
                 critic_value_ = self.target_critic(torch.concat((new_states, target_actions), dim=-1))
             critic_value = self.critic(torch.concat((states, actions), dim=-1))
             #target = torch.addcmul(rewards, self.gamma, 1 - dones, critic_value_.squeeze()).view(self.batch_size, 1)
@@ -91,7 +92,7 @@ class DDPG(ValueBasedAgent):
             self.critic.learn(critic_loss)
 
             actions = self.actor(states)
-            actions = self.scale_action(actions, Box(-1, 1, (self.nb_actions,)))
+            actions = scale_tensor(actions, Box(-1, 1, (self.nb_actions,)), self.action_space)
             actor_loss = - self.critic(torch.concat((states, actions), dim=-1))
             actor_loss = torch.mean(actor_loss)
             self.actor.learn(actor_loss)
