@@ -9,6 +9,7 @@ from gym.spaces import Box
 from torch.nn import ReLU, Tanh
 from torch.nn.functional import normalize
 
+from hbrl.agents.utils import scale_tensor
 from hbrl.agents.utils.mlp import MLP
 from hbrl.agents.value_based_agent import ValueBasedAgent
 from torch import optim
@@ -100,7 +101,7 @@ class SAC(ValueBasedAgent):
         actions = torch.tanh(raw_actions)
         log_probs -= torch.log(1 - actions.pow(2) + 1e-6)
         log_probs = log_probs.sum(-1)
-        actions = self.scale_action(actions, Box(-1, 1, (self.nb_actions,)))
+        actions = scale_tensor(actions, Box(-1, 1, (self.nb_actions,)), self.action_space)
         return actions, log_probs
 
     def action(self, state, explore=True):
