@@ -1,4 +1,5 @@
 # Goal conditioned deep Q-network
+from ..utils import scale_tensor
 from ..value_based_agent import ValueBasedAgent
 from ..utils.mlp import MLP
 import copy
@@ -77,6 +78,8 @@ class DQN(ValueBasedAgent):
             with torch.no_grad():
                 q_values = self.model(state)
                 action = torch.argmax(q_values).item()
+
+        action = scale_tensor(action, Box(-1, 1, (self.nb_actions,)), self.action_space)
         return action
 
     def learn(self):
